@@ -5,11 +5,11 @@ use crate::{
 };
 use fltk::{prelude::*, *};
 use parking_lot::Mutex;
-use std::sync::{atomic::Ordering, Arc};
+use std::sync::Arc;
 use sysinfo::System;
 use sysinfo::SystemExt;
 
-pub fn memory(view: &MyView) -> group::Pack {
+pub fn memory(view: &MyView) -> Option<Box<dyn FnMut() + Send>> {
     let mut sys = view.system.lock();
     sys.refresh_memory();
     frame::Frame::new(60, 60, 0, 0, None);
@@ -87,30 +87,23 @@ pub fn memory(view: &MyView) -> group::Pack {
     grp.end();
     let dials = Arc::new(Mutex::new(dials));
     let sys = Arc::new(Mutex::new(System::new_all()));
-    let sleep = view.sleep.clone();
-    std::thread::spawn({
-        move || loop {
-            if let Some(mut sys) = sys.try_lock() {
-                sys.refresh_memory();
-                dials.lock()[0].set_value(
-                    (sys.used_memory() as f64 / sys.total_memory() as f64 * 100.) as i32,
-                );
-                used_mem.set_label(&format!(
-                    "Used: {:.02} GiB",
-                    sys.used_memory() as f64 / 2_f64.powf(20.)
-                ));
-                dials.lock()[1]
-                    .set_value((sys.used_swap() as f64 / sys.total_swap() as f64 * 100.) as i32);
-                used_swap.set_label(&format!(
-                    "Used: {:.02} GiB",
-                    sys.used_swap() as f64 / 2_f64.powf(20.)
-                ));
-                app::awake();
-            }
-            std::thread::sleep(std::time::Duration::from_millis(
-                sleep.load(Ordering::Relaxed),
+    let cb = move || {
+        if let Some(mut sys) = sys.try_lock() {
+            sys.refresh_memory();
+            dials.lock()[0]
+                .set_value((sys.used_memory() as f64 / sys.total_memory() as f64 * 100.) as i32);
+            used_mem.set_label(&format!(
+                "Used: {:.02} GiB",
+                sys.used_memory() as f64 / 2_f64.powf(20.)
             ));
+            dials.lock()[1]
+                .set_value((sys.used_swap() as f64 / sys.total_swap() as f64 * 100.) as i32);
+            used_swap.set_label(&format!(
+                "Used: {:.02} GiB",
+                sys.used_swap() as f64 / 2_f64.powf(20.)
+            ));
+            app::awake();
         }
-    });
-    grp
+    };
+    Some(Box::new(cb))
 }
